<?php
/**
 * Metaboxes with design options
 *
 * @package WordPress
 * @subpackage SEO
 */

?>
<?php
add_action( 'add_meta_boxes', 'diagnoseo_page_metaboxes', 10, 2 );
add_action( 'save_post', 'diagnoseo_save_metabox' );

/**
 * Adds metaboxes to page editor
 */
function diagnoseo_page_metaboxes() {
	$post_types = array( 'page', 'post' );
	foreach ( $post_types as $type ) {
		add_meta_box( 'display-options', esc_html__( 'SEO Friendly: Display Options', 'diagnoseo' ), 'diagnoseo_draw_display_metabox', $type, 'side', 'default' );
	}
}

/**
 * Renders the metabox
 *
 * @param object $post Currently edited post object.
 */
function diagnoseo_draw_display_metabox( $post ) {
	global $post;
	$data             = get_post_custom( $post->ID );
	$show_title       = isset( $data['seo-friendly-show-title'] ) ? $data['seo-friendly-show-title'][0] : 0;
	$show_breadcrumbs = isset( $data['seo-friendly-show-breadcrumbs'] ) ? $data['seo-friendly-show-breadcrumbs'][0] : 0;
	$sidebar_position = isset( $data['seo-friendly-sidebar-position'] ) ? $data['seo-friendly-sidebar-position'][0] : 0;

	wp_nonce_field( 'diagnoseo_display_metabox_nonce', 'display_metabox_nonce' );
	?>
	<div class="seo-friendly-metabox">
		<div class="components-base-control__field">
			<label for="show_title" class="components-base-control__label"><?php esc_html_e( 'Show title', 'diagnoseo' ); ?></label>
			<select name="show_title" id="show_title" class="widefat">
				<option value="on" <?php if ( 'on' === $show_title ) : ?>
					selected="selected"
				<?php endif; ?>><?php esc_html_e( 'On', 'diagnoseo' ); ?></option>
				<option value="off" <?php if ( 'off' === $show_title ) : ?>
					selected="selected"<?php endif; ?>><?php esc_html_e( 'Off', 'diagnoseo' ); ?></option>
			</select>
		</div>

		<div class="components-base-control__field">
			<label for="show_breadcrumbs" class="components-base-control__label"><?php esc_html_e( 'Show breadcrumbs', 'diagnoseo' ); ?></label>
			<select name="show_breadcrumbs" id="show_breadcrumbs" class="widefat">
				<option value="" <?php if ( '' === $show_breadcrumbs ) : ?>
					selected="selected"
				<?php endif; ?>><?php esc_html_e( 'As set in Theme Customizer', 'diagnoseo' ); ?></option>
				<option value="on" <?php if ( 'on' === $show_breadcrumbs ) : ?>
					selected="selected"
				<?php endif; ?>><?php esc_html_e( 'On', 'diagnoseo' ); ?></option>
				<option value="off" <?php if ( 'off' === $show_breadcrumbs ) : ?>
					selected="selected"<?php endif; ?>><?php esc_html_e( 'Off', 'diagnoseo' ); ?></option>
			</select>
		</div>

		<div class="components-base-control__field">
			<label for="sidebar_position" class="components-base-control__label"><?php esc_html_e( 'Sidebar position', 'diagnoseo' ); ?></label>
			<select name="sidebar_position" id="sidebar_position" class="widefat">
				<option value="" <?php if ( '' === $sidebar_position ) : ?>
					selected="selected"<?php endif; ?>><?php esc_html_e( 'As set in Theme Customizer', 'diagnoseo' ); ?></option>
				<option value="right" <?php if ( 'right' === $sidebar_position ) : ?>
					selected="selected"<?php endif; ?>><?php esc_html_e( 'Right', 'diagnoseo' ); ?></option>
				<option value="left" <?php if ( 'left' === $sidebar_position ) : ?>
					selected="selected"<?php endif; ?>><?php esc_html_e( 'Left', 'diagnoseo' ); ?></option>
				<option value="none" <?php if ( 'none' === $sidebar_position ) : ?>
					selected="selected"<?php endif; ?>><?php esc_html_e( "Don't show", 'diagnoseo' ); ?></option>
			</select>
		</div>
	</div>
	<?php
}

/**
 * Saves text metabox value
 *
 * @param integer $post_id ID of currently edited post.
 * @param string  $meta_key The name of a custom field to save the value to.
 * @param string  $value The new value of the custom field.
 */
function diagnoseo_save_meta_textfield( $post_id, $meta_key, $value ) {
	if ( '' === $value && get_post_meta( $post_id, $meta_key, true ) ) {
		delete_post_meta( $post_id, $meta_key );
	}
	if ( '' !== $value ) {
		update_post_meta( $post_id, $meta_key, sanitize_text_field( wp_unslash( $value ) ) );
	}
}

/**
 * Saves number metabox value
 *
 * @param integer $post_id ID of currently edited post.
 * @param string  $meta_key The name of a custom field to save the value to.
 * @param string  $value The new value of the custom field.
 */
function diagnoseo_save_meta_number( $post_id, $meta_key, $value ) {
	if ( '' === $value && '' !== get_post_meta( $post_id, $meta_key, true ) ) {
		delete_post_meta( $post_id, $meta_key );
	}
	if ( '' !== $value ) {
		update_post_meta( $post_id, $meta_key, absint( wp_unslash( $value ) ) );
	}
}

/**
 * Saves all the metabox values
 *
 * @param integer $post_id ID of currently edited post.
 */
function diagnoseo_save_metabox( $post_id ) {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	if ( ! isset( $_POST['display_metabox_nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['display_metabox_nonce'] ) ), 'diagnoseo_display_metabox_nonce' ) ) {
		return;
	}
	if ( ! current_user_can( 'edit_pages', $post_id ) ) {
		return;
	}

	if ( isset( $_POST['show_title'] ) ) {
		diagnoseo_save_meta_textfield( $post_id, 'seo-friendly-show-title', sanitize_text_field( wp_unslash( $_POST['show_title'] ) ) );
	}
	if ( isset( $_POST['show_breadcrumbs'] ) ) {
		diagnoseo_save_meta_textfield( $post_id, 'seo-friendly-show-breadcrumbs', sanitize_text_field( wp_unslash( $_POST['show_breadcrumbs'] ) ) );
	}
	if ( isset( $_POST['sidebar_position'] ) ) {
		diagnoseo_save_meta_textfield( $post_id, 'seo-friendly-sidebar-position', sanitize_text_field( wp_unslash( $_POST['sidebar_position'] ) ) );
	}
}
